@@ -99,6 +99,7 @@ class mysql(object):
 		return data
 	def add(self,dicts,table=None):
 		'''table is optional,dicts can be list or dict'''
+		if not dicts:return
 		if not isinstance(table,str):
 			if table is None:
 				table=self.table
@@ -114,6 +115,7 @@ class mysql(object):
 		return self.execute(r''' insert `%s`(%s) values%s '''%(table,key,values[:-1]))
 	def update(self,where,data,table=None):
 		'''where can be str or dict'''
+		if not data:return
 		if table is None:
 			table=self.table
 		if isinstance(where,dict) : where=self._split_dict(where,'and')
